@@ -2,7 +2,7 @@
 # citation
 #################################################################################################################
 .onAttach <- function(libname, pkgname) {
-  package_citation <- "Li, S. (2023). IRTest: Parameter estimation of item response theory with estimation of latent distribution (Version 1.12.0). R package. \n"
+  package_citation <- "Li, S. (2024). IRTest: Parameter estimation of item response theory with estimation of latent distribution (Version 2.0.0). R package. \n"
   package_URL <- "URL: https://CRAN.R-project.org/package=IRTest"
   packageStartupMessage("Thank you for using IRTest!")
   packageStartupMessage("Please cite the package as: \n")
@@ -133,10 +133,11 @@ logLikeli <- function(item, data, theta){
 }
 
 logLikeli_Poly <- function(item, data, theta, model){
+  b_pars <- if(nrow(item)==1) item[,-1,drop=FALSE] else item[,-1]
   if(model %in% c("PCM", "GPCM")){
-    pmat <- P_P(theta = theta, a = item[,1], b = item[,-1])
+    pmat <- P_P(theta = theta, a = item[,1], b = b_pars)
   } else if(model == "GRM"){
-    pmat <- P_G(theta = theta, a = item[,1], b = item[,-1])
+    pmat <- P_G(theta = theta, a = item[,1], b = b_pars)
   }
 
   L <- NULL
@@ -158,7 +159,28 @@ logLikeli_Poly <- function(item, data, theta, model){
   return(L)
 }
 
+#' @importFrom stats dbeta
+#'
+logLikeli_Cont <- function(item, data, theta){
+  p <- P(theta = theta, a = item[,1], b = item[,2])
 
+  L <- NULL
+  for(i in 1:nrow(item)){
+    L <- cbind(L, dbeta(x = data[,i],
+                        shape1 = p[i]*item[i,3],
+                        shape2 = (1-p[i])*item[i,3],
+                        log = TRUE)
+               )
+  }
+  L <- rowSums(L, na.rm = TRUE)
+  L[L==-Inf] <- -.Machine$double.xmax
+  return(L)
+}
+
+# log_P_cont <- function(response, theta, a, b, phi){
+#   mu <- P(theta, a, b)
+#   return(dbeta(x=response, shape1 = mu*phi, shape2 = (1-mu)*phi, log = TRUE))
+# }
 #################################################################################################################
 # E step
 #################################################################################################################
@@ -248,6 +270,27 @@ Estep_Mix <- function(item_D, item_P, data_D, data_P, range = c(-4,4), q = 100,
   fk <- colSums(Pk) # expected frequency of examinees
   return(list(Xk=Xk, Ak=Ak, fk=fk, rik_D=rik_D, rik_P=rik_P, Pk=Pk))
 }
+
+Estep_Cont <- function(item, data, range = c(-4,4), q = 81, prob = 0.5, d = 0,
+                  sd_ratio = 1,Xk=NULL, Ak=NULL){
+  if(is.null(Xk)) {
+    # quadrature points
+    Xk <- seq(range[1],range[2],length=q)
+  }
+  if(is.null(Ak)) {
+    # heights for quadrature points
+    Ak <- dist2(Xk, prob, d, sd_ratio)/sum(dist2(Xk, prob, d, sd_ratio))
+  }
+  Pk <- matrix(nrow = nrow(data), ncol = q)
+  for(i in 1:q){
+    # weighted likelihood where the weight is the latent distribution
+    Pk[,i] <- exp(logLikeli_Cont(item = item, data = data, theta = Xk[i]))*Ak[i]
+  }
+  Pk <- Pk/rowSums(Pk) # posterior weights
+  # rik <- crossprod(data, t(t(Pk)/rowSums(t(Pk))), na.rm=TRUE)
+  fk <- colSums(Pk) # expected frequency of examinees
+  return(list(Xk=Xk, Ak=Ak, fk=fk, Pk=Pk))
+}
 #################################################################################################################
 # M1 step
 #################################################################################################################
@@ -625,6 +668,71 @@ PDs <- function(probab, param, pmat, pcummat, a_supp, par, tcum){
   }
 }
 
+#' @importFrom stats optim
+#'
+Mstep_Cont <- function(E, item, data){
+  item_estimated <- item
+  item[,3] <- log(item[,3])
+  for(i in 1:nrow(item)){
+    item_estimated[i,] <- optim(item[i,], fn = LL_Cont, gr = grad_Cont, theta=E$Xk, data=data[,i], Pk = E$Pk, method = "BFGS")$par
+  }
+  item_estimated[,3] <- exp(item_estimated[,3])
+  return(item_estimated)
+}
+
+# LL_Cont <- function(item, theta, data, Pk){
+#   nu <- exp(item[3])
+#   LL <- 0
+#   for(i in 1:length(theta)){
+#     mu <- P(theta = theta[i], a = item[1], b = item[2])
+#     alpha <- mu*nu
+#     beta <- nu*(1-mu)
+#     LL <- LL+sum(Pk[,i]*log(dbeta(data, alpha, beta)), na.rm = TRUE)
+#   }
+#   return(-LL)
+# }
+#' @importFrom stats dbeta
+#'
+LL_Cont <- function(item, theta, data, Pk){
+  nu <- exp(item[3])
+  mu <- P(theta = rep(theta, each=nrow(Pk)), a = item[1], b = item[2])
+  alpha <- mu*nu
+  beta <- nu*(1-mu)
+  LL <- sum(as.vector(Pk)*log(dbeta(rep(data, times=ncol(Pk)), alpha, beta)), na.rm = TRUE)
+  return(-LL)
+}
+
+# grad_Cont <- function(item, theta, data, Pk){
+#   item[3] <- exp(item[3])
+#   La <- 0
+#   Lb <- 0
+#   Lnu <- 0
+#   for(i in 1:length(theta)){
+#     mu <- P(theta = theta[i], a = item[1], b = item[2])
+#     alpha <- mu*item[3]
+#     beta <- item[3]*(1-mu)
+#     v1 <- log(data)-digamma(alpha)
+#     v2 <- log(1-data)-digamma(beta)
+#     La  <- La + sum(Pk[,i]*(theta[i]-item[2])*item[3]*mu*(1-mu)*(v1-v2), na.rm = TRUE)
+#     Lb  <- Lb + sum(-Pk[,i]*item[1]*item[3]*mu*(1-mu)*(v1-v2), na.rm = TRUE)
+#     Lnu <- Lnu + sum(Pk[,i]*(mu*v1+(1-mu)*v2+digamma(item[3])), na.rm = TRUE)
+#   }
+#
+#   return(-c(La, Lb, Lnu))
+# }
+grad_Cont <- function(item, theta, data, Pk){
+  nu <- exp(item[3])
+  mu <- P(theta = rep(theta, each=nrow(Pk)), a = item[1], b = item[2])
+  alpha <- mu*nu
+  beta <- nu*(1-mu)
+  v1 <- log(rep(data, times=ncol(Pk)))-digamma(alpha)
+  v2 <- log(1-rep(data, times=ncol(Pk)))-digamma(beta)
+  La <- sum(as.vector(Pk)*(rep(theta, each=nrow(Pk))-item[2])*nu*mu*(1-mu)*(v1-v2), na.rm = TRUE)
+  Lb <- sum(-as.vector(Pk)*item[1]*nu*mu*(1-mu)*(v1-v2), na.rm = TRUE)
+  Lnu <- sum(as.vector(Pk)*(mu*v1+(1-mu)*v2+digamma(nu)), na.rm = TRUE)
+  return(-c(La, Lb, Lnu))
+}
+
 #################################################################################################################
 # M2 step
 #################################################################################################################
@@ -769,11 +877,44 @@ MLE_theta <- function(item, data, type){
         se <- append(se, sqrt(-1/l1l2[2]))
       }
     }
+  } else if(all(type=="cont")){
+    for(i in 1:nrow(data)){
+      message("\r","\r","MLE for ability parameter estimation, ", i,"/",nrow(data),sep="",appendLF=FALSE)
+
+      th <- 0
+      thres <- 1
+      while(thres > 0.0001){
+        L1 <- L1_Cont(data = data[i,], theta = th, a = item[,1], b = item[,2], nu = item[,3])
+        L2 <- -L2_Cont(theta = th, a = item[,1], b = item[,2], nu = item[,3])
+        diff <- sum(L1, na.rm = TRUE)/sum(L2, na.rm = TRUE)
+        th <- th - diff
+        thres <- abs(diff)
+      }
+      mle <- append(mle, th)
+      se <- append(se, sqrt(-1/sum(L2, na.rm = TRUE)))
+    }
   }
   return(list(mle=mle,
               se=se))
 }
 
+L1_Cont <- function(data, theta, a, b, nu=20){
+  mu <- P(theta, a, b)
+  alpha <- mu*nu
+  beta <- nu*(1-mu)
+  grad <- (a*alpha*beta/nu)*(-digamma(alpha)+digamma(beta)+log(data/(1-data)))
+  return(grad)
+}
+
+L2_Cont <- function(theta, a, b, nu=20){
+  mu <- P(theta, a, b)
+  alpha <- mu*nu
+  beta <- nu*(1-mu)
+  inform <- (a*alpha*beta/nu)^2*(trigamma(alpha)+trigamma(beta))
+  return(inform)
+}
+# plot(seq(-4,4,length=81), inform_Cont(seq(-4,4,length=81), 1, 0, 5))
+
 L1L2_Poly <- function(th, item, data, type, ncat, i){
   if(type %in% c("PCM", "GPCM")){
     p <- P_P(theta = th, a = item[,1], b = item[,-1])
